
# PYICLOUDNG

Python libraries to interact with Apple icloud. This is a fork from PYICLOUD library 

## Description 

Python libraries to interact with Apple icloud 

## Author


Name: JordiRedondo 
Email: redcorjo@gmail.com


Version: 0.0.1